webcouturier.dropdownmenu
=========================

Less Compilation
----

To udpate/generate css from less, use the following snippet


  ::

   lessc --modify-var="plone-link-color=#007bb1" --source-map=webcouturier.dropdownmenu-compiled.css.map dropdown.less webcouturier.dropdownmenu-compiled.css

